==> net.bluemind.p2.platform-4.9.3879.zip: net/bluemind/videoconferencing/api/gwt/endpoint/VideoConferencingSockJsEndpoint.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.videoconferencing.api.gwt.endpoint;

import net.bluemind.core.api.AsyncHandler;
import net.bluemind.core.commons.gwt.EndpointRequestCallback;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.json.client.JSONValue;
import com.google.gwt.json.client.JSONObject;
import net.bluemind.restbus.api.gwt.AsyncHandlerAdapter;
import java.util.List;
import java.util.Map;
import java.util.Set;
import net.bluemind.core.api.Stream;
import java.lang.Long;
import net.bluemind.restbus.api.gwt.GwtRestRequest;
import net.bluemind.restbus.api.gwt.GwtRestResponse;
import net.bluemind.restbus.api.gwt.RestBusImpl;

public class VideoConferencingSockJsEndpoint implements net.bluemind.videoconferencing.api.IVideoConferencingAsync {

	private String rootUri = "/api";

	private String baseUri;

    private String sessionId;

	public VideoConferencingSockJsEndpoint(String sessionId, String... pathVars) {
		String uri_ = "/videoconferencing/{containerUid}";
		this.sessionId = sessionId;
	
		uri_ = uri_.replace("{containerUid}",pathVars[0]);
		
		baseUri = uri_;
	}

	public VideoConferencingSockJsEndpoint withRoot(String root) {
		this.rootUri = root;
		return this;
	}

	@Override
	public void add(net.bluemind.calendar.api.VEvent vevent, final AsyncHandler<net.bluemind.calendar.api.VEvent> handler) {
		String postUri = "";

		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;
		JSONValue jsonValue = new net.bluemind.calendar.api.gwt.serder.VEventGwtSerDer().serialize( vevent);
		if( jsonValue != null) {
			bodyContent = jsonValue.isObject().getJavaScriptObject();
		}

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"PUT",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<net.bluemind.calendar.api.VEvent>(handler) {
					@Override
			protected net.bluemind.calendar.api.VEvent handleResponse(
							JSONValue jsonValue) {
				return new net.bluemind.calendar.api.gwt.serder.VEventGwtSerDer().deserialize( jsonValue );
			}
		});

	}


	@Override
	public void createResource(String uid, net.bluemind.videoconferencing.api.VideoConferencingResourceDescriptor descriptor, final AsyncHandler<Void> handler) {
		String postUri = "/createResource/{uid}";

		postUri = postUri.replace("{uid}", ""+uid);
		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;
		JSONValue jsonValue = new net.bluemind.videoconferencing.api.gwt.serder.VideoConferencingResourceDescriptorGwtSerDer().serialize( descriptor);
		if( jsonValue != null) {
			bodyContent = jsonValue.isObject().getJavaScriptObject();
		}

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"PUT",rootUri + uri_,params, bodyContent);
		
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<Void>(handler) {
					@Override
			protected Void handleResponse(
							JSONValue jsonValue) {
				return null;
			}
		});

	}


	@Override
	public void remove(net.bluemind.calendar.api.VEvent vevent, final AsyncHandler<net.bluemind.calendar.api.VEvent> handler) {
		String postUri = "";

		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;
		JSONValue jsonValue = new net.bluemind.calendar.api.gwt.serder.VEventGwtSerDer().serialize( vevent);
		if( jsonValue != null) {
			bodyContent = jsonValue.isObject().getJavaScriptObject();
		}

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"DELETE",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<net.bluemind.calendar.api.VEvent>(handler) {
					@Override
			protected net.bluemind.calendar.api.VEvent handleResponse(
							JSONValue jsonValue) {
				return new net.bluemind.calendar.api.gwt.serder.VEventGwtSerDer().deserialize( jsonValue );
			}
		});

	}

	public net.bluemind.videoconferencing.api.IVideoConferencingPromise promiseApi() {
		return new VideoConferencingEndpointPromise(this);
	}

}

==> net.bluemind.p2.platform-5.4.2760.zip: net/bluemind/videoconferencing/api/gwt/endpoint/VideoConferencingSockJsEndpoint.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.videoconferencing.api.gwt.endpoint;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.http.client.URL;
import com.google.gwt.json.client.JSONValue;
import com.google.gwt.json.client.JSONObject;

import java.util.List;
import java.util.Map;
import java.util.Set;
import java.lang.Long;

import net.bluemind.core.api.AsyncHandler;
import net.bluemind.core.api.Stream;
import net.bluemind.core.commons.gwt.EndpointRequestCallback;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;
import net.bluemind.restbus.api.gwt.AsyncHandlerAdapter;
import net.bluemind.restbus.api.gwt.GwtRestRequest;
import net.bluemind.restbus.api.gwt.GwtRestResponse;
import net.bluemind.restbus.api.gwt.RestBusImpl;

public class VideoConferencingSockJsEndpoint implements net.bluemind.videoconferencing.api.IVideoConferencingAsync {

	private String rootUri = "/api";

	private String baseUri;

    private String sessionId;

	public VideoConferencingSockJsEndpoint(String sessionId, String... pathVars) {
		String uri_ = "/videoconferencing/{containerUid}";
		this.sessionId = sessionId;
	
		uri_ = uri_.replace("{containerUid}", URL.encodePathSegment(pathVars[0]));
		
		baseUri = uri_;
	}

	public VideoConferencingSockJsEndpoint withRoot(String root) {
		this.rootUri = root;
		return this;
	}

	@Override
	public void add(net.bluemind.calendar.api.VEvent vevent, final AsyncHandler<net.bluemind.calendar.api.VEvent> handler) {
		String postUri = "";

		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;
		JSONValue jsonValue = new net.bluemind.calendar.api.gwt.serder.VEventGwtSerDer().serialize( vevent);
		if( jsonValue != null) {
			bodyContent = jsonValue.isObject().getJavaScriptObject();
		}

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"PUT",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<net.bluemind.calendar.api.VEvent>(handler) {
					@Override
			protected net.bluemind.calendar.api.VEvent handleResponse(
							JSONValue jsonValue) {
				return new net.bluemind.calendar.api.gwt.serder.VEventGwtSerDer().deserialize( jsonValue );
			}
		});

	}


	@Override
	public void createResource(String uid, net.bluemind.videoconferencing.api.VideoConferencingResourceDescriptor descriptor, final AsyncHandler<Void> handler) {
		String postUri = "/createResource/{uid}";

		postUri = postUri.replace("{uid}", URL.encodePathSegment(""+uid));
		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;
		JSONValue jsonValue = new net.bluemind.videoconferencing.api.gwt.serder.VideoConferencingResourceDescriptorGwtSerDer().serialize( descriptor);
		if( jsonValue != null) {
			bodyContent = jsonValue.isObject().getJavaScriptObject();
		}

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"PUT",rootUri + uri_,params, bodyContent);
		
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<Void>(handler) {
					@Override
			protected Void handleResponse(
							JSONValue jsonValue) {
				return null;
			}
		});

	}


	@Override
	public void remove(net.bluemind.calendar.api.VEvent vevent, final AsyncHandler<net.bluemind.calendar.api.VEvent> handler) {
		String postUri = "";

		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;
		JSONValue jsonValue = new net.bluemind.calendar.api.gwt.serder.VEventGwtSerDer().serialize( vevent);
		if( jsonValue != null) {
			bodyContent = jsonValue.isObject().getJavaScriptObject();
		}

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"DELETE",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<net.bluemind.calendar.api.VEvent>(handler) {
					@Override
			protected net.bluemind.calendar.api.VEvent handleResponse(
							JSONValue jsonValue) {
				return new net.bluemind.calendar.api.gwt.serder.VEventGwtSerDer().deserialize( jsonValue );
			}
		});

	}

	public net.bluemind.videoconferencing.api.IVideoConferencingPromise promiseApi() {
		return new VideoConferencingEndpointPromise(this);
	}

}
